/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Object from '../Object';
import Type from '../Type';
/**
 * This class provides a structure for a key/value pair.
 * @extends Object
 */
export declare class KeyValuePair<TKey extends Object, TValue extends Object> extends Object {
    /**
     * Create a new instance with the given key/value pair.
     * @param {Obj} key The key of the pair.
     * @param {Obj} value The value of the pair.
     */
    constructor(key: TKey, value: TValue);
    private _key;
    private _value;
    /**
     * The key of this pair.
     */
    readonly key: TKey;
    /**
     * The value of this pair.
     */
    readonly value: TValue;
    /**
     * Compares this pair with an other object for equality.
     * @param {KeyValuePair|Object} other The object to compare with.
     * @return {boolean} Returns true, if the objects are equal, otherwise false.
     */
    equals(other: (KeyValuePair<TKey, TValue> | Object)): boolean;
    /**
     * Returns the type of this pair for further reflection.
     * @return {Type} Returns the type of this pair.
     */
    getType(): Type;
}
export default KeyValuePair;
