/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Exception from './Exception';
import SystemException from './SystemException';
import Type from '../Type';
/**
 * The ArgumentException will be thrown, when an invalid argument has been
 * provided to the function.
 *
 * @extends SystemException
 */
export declare class ArgumentException extends SystemException {
    /**
     * Creates a new ArgumentException object with an optional parameter name,
     * an optional error message, and an optional inner Exception object that
     * causes this ArgumentException.
     *
     * @param paramName
     * The name of the parameter, that caused the ArgumentException.
     *
     * @param message
     * The error message for this ArgumentException.
     *
     * @param innerException
     * The inner Exception as the cause of this ArgumentException.
     */
    constructor(paramName?: (string | null), message?: (string | null), innerException?: (Exception | null));
    private _paramName;
    /**
     * The error message of this ArgumentException.
     */
    readonly message: (string | null);
    /**
     * The name of the parameter, that caused this ArgumentException.
     */
    readonly paramName: (string | null);
    /**
     * Returns the type of this ArgumentException for further reflection.
     *
     * @return {Type}
     * The type of this ArgumentException.
     */
    getType(): Type;
}
export default ArgumentException;
