/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import ArgumentException from './ArgumentException';
import Exception from './Exception';
import Object from '../Object';
import Type from '../Type';
/**
 * The ArgumentOutOfRangeException will be thrown, when an invalid value for an
 * argument has been provided to the function.
 *
 * @extends ArgumentException
 */
export declare class ArgumentOutOfRangeException extends ArgumentException {
    /**
     * Creates a ArgumentOutOfRangeException object with an optional parameter
     * name, an optional actual, an optional error message, and an optional
     * inner Exception object that causes this ArgumentOutOfRangeException.
     *
     * @param paramName
     * The name of the parameter, that caused the ArgumentOutOfRangeException.
     *
     * @param actualValue
     * The actual value of the parameter, that caused the
     * ArgumentOutOfRangeException.
     *
     * @param message
     * The error message for this ArgumentOutOfRangeException.
     *
     * @param innerException
     * The inner Exception as the cause of this ArgumentOutOfRangeException.
     */
    constructor(paramName?: string, actualValue?: (Object | boolean | number | string | null), message?: string, innerException?: Exception);
    private _actualValue;
    /**
     * The error message of this ArgumentOutOfRangeException.
     */
    readonly message: (string | null);
    /**
     * The value of the parameter, that caused this ArgumentOutOfRangeException.
     */
    readonly actualValue: (Object | boolean | number | string | null);
    /**
     * Returns the type of this ArgumentOutOfRangeException for further reflection.
     *
     * @return {Type}
     * The type of this ArgumentOutOfRangeException.
     */
    getType(): Type;
}
export default ArgumentOutOfRangeException;
