/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IDictionary from '../Collections/IDictionary';
import Object from '../Object';
import String from '../Primitives/String';
import Type from '../Type';
/**
 * The base class for every exceptional error that can occur during execution.
 *
 * @extends Object
 */
export declare class Exception extends Object {
    /**
     * Creates a new Exception with an optional error message and an optional
     * inner Exception that causes this Exception.
     *
     * @param message
     * The error message for this Exception.
     *
     * @param innerException
     * The inner exception as the cause of this exception.
     */
    constructor(message?: (string | null), innerException?: (Exception | null));
    private _data;
    private _error;
    private _finalized;
    private _helpLink;
    private _innerException;
    private _message;
    private _source;
    /**
     * Contains custom data for this exception.
     */
    readonly data: IDictionary<String, Object>;
    /**
     * A URI link to the associated help file.
     */
    helpLink: (string | null);
    /**
     * The cause of the current exception.
     */
    readonly innerException: (Exception | null);
    /**
     * The error message of this exception.
     */
    readonly message: (string | null);
    /**
     * The name of the object that causes the error.
     */
    source: (string | null);
    /**
     * The call stack during the creation or throwing of the Exception.
     */
    readonly stackTrace: string;
    /**
     * Finalize this exception object for immediate throw and overwrites the
     * stack trace.
     *
     * @exception {Exception}
     * This exception object.
     */
    finalize(): Exception;
    /**
     * Returns the class name of the base Exception for furhter handling.
     *
     * @return {string}
     * The base Exception of this Exception chain.
     */
    getBaseException(): Exception;
    /**
     * Returns the type of this Exception for further reflection.
     *
     * @return {Type}
     * The type of this Exception.
     */
    getType(): Type;
    /**
     * Returns the a detailed string of this Exception.
     *
     * @param includeStackTrace
     * Set false to exclude the stack trace.
     *
     * @param includeMessage
     * Set false to exclude the error message.
     *
     * @return {string}
     * The string of this exception object.
     */
    toString(includeStackTrace?: boolean, includeMessage?: boolean): string;
}
export default Exception;
