"use strict";
/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
Object.defineProperty(exports, "__esModule", { value: true });
const package_1 = require("../../package");
const Environment_1 = require("../Runtime/Environment");
const LinkedList_1 = require("../Collections/LinkedList");
const Object_1 = require("../Object");
const Type_1 = require("../Type");
class Exception extends Object_1.default {
    constructor(message = null, innerException = null) {
        super();
        this._finalized = false;
        this._helpLink = null;
        this._innerException = innerException;
        this._message = message;
        try {
            throw new Error(this.message ? this.message.toString() : undefined);
        }
        catch (error) {
            this._error = error;
        }
    }
    get data() {
        if (this._data === undefined) {
            this._data = new LinkedList_1.default();
        }
        return this._data;
    }
    get helpLink() {
        return this._helpLink;
    }
    set helpLink(value) {
        this._helpLink = value;
    }
    get innerException() {
        return this._innerException;
    }
    get message() {
        return this._message;
    }
    get source() {
        return this._source;
    }
    set source(value) {
        this._source = value;
    }
    get stackTrace() {
        return (this._error.stack || Environment_1.default.NEWLINE + '    stack not available').replace(REGEXP_REMOVE_FIRST_LINE, '');
    }
    finalize() {
        if (this._finalized) {
            return this;
        }
        try {
            throw new Error(this._message ? this._message.toString() : undefined);
        }
        catch (error) {
            this._error = error;
        }
        finally {
            this._finalized = true;
            return this;
        }
    }
    getBaseException() {
        let baseException = this;
        while (baseException.innerException != null) {
            baseException = baseException.innerException;
        }
        return baseException;
    }
    getType() {
        return new Type_1.default(this, package_1.default);
    }
    toString(includeStackTrace = true, includeMessage = true) {
        let str = '';
        if (includeMessage
            && this.message !== null) {
            str += this.message;
        }
        let stackTrace = this.stackTrace;
        if (includeStackTrace
            && stackTrace !== '') {
            if (str !== '') {
                str += Environment_1.default.NEWLINE;
            }
            str += stackTrace;
        }
        if (str === '') {
            return this.getType().fullName;
        }
        else {
            return this.getType().fullName + ': ' + str;
        }
    }
}
exports.Exception = Exception;
exports.default = Exception;
const REGEXP_REMOVE_FIRST_LINE = new RegExp('^[^' + Environment_1.default.NEWLINE_ALL.join('') + ']*(?:[' + Environment_1.default.NEWLINE_ALL.join('') + ']+|$)');
