/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Environment from './Runtime/Environment';
import { Type } from './';
/**
 * The base class for all other classes.
 */
declare class _Object_ extends Environment.ESOBJECT {
    private _hashCode_;
    /**
     * Compares this object with an other object for equality.
     *
     * @param {Object} other
     * The object to compare with.
     *
     * @return {boolean|any}
     * True, if the objects are equal, otherwise false.
     */
    equals(other: _Object_): boolean;
    /**
     * Generates or returns a unique code for this object. Should be
     * overwritten by value based classes.
     *
     * @return {number}
     * The unique code for this object.
     */
    getHashCode(): number;
    /**
     * Returns the type of an object for further reflection. Must be
     * overwritten by every class.
     *
     * @return {Type}
     * The type of this object.
     */
    getType(): Type;
    /**
     * Returns the class name as the default string representation of an
     * object. Must be overwritten by value based classes.
     *
     * @return {string}
     * The string representation of this object.
     */
    toString(): string;
    /**
     * Returns the primitive value of an object. Must be overwritten by value
     * based classes.
     *
     * @return {boolean|number|string}
     * The primitive value of this object.
     */
    valueOf(): (boolean | number | string);
}
export default _Object_;
