/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Type from '../Type';
import ValueType from './ValueType';
/**
 * Represents a character as a UTF-32 code unit.
 * @extends ValueType
 */
export declare class Char extends ValueType<number> {
    /**
     * Converts the first element of the string into a char.
     * @param {string} charString The provided string for conversion.
     * @return {Char} The resulting char after conversion.
     */
    static tryParse(charString: string): Char;
    /**
     * Filters the primitive value at initialization.
     * @param {number|ValueType|undefined} value The provided number.
     * @return {number} The filtered number.
     */
    protected filter(value: (number | ValueType<number> | undefined)): number;
    /**
     * Returns the type of the char for further reflection.
     * @return {Type} Returns the type of this char.
     */
    getType(): Type;
    /**
     * Converts the char to a string.
     * @returns {string} The string equivalent of this char.
     */
    toString(): string;
}
export default Char;
