"use strict";
/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
Object.defineProperty(exports, "__esModule", { value: true });
const package_1 = require("../../package");
const Environment_1 = require("../Runtime/Environment");
const Type_1 = require("../Type");
const ValueType_1 = require("./ValueType");
class Char extends ValueType_1.default {
    static tryParse(charString) {
        if (charString.length == 0) {
            return new Char();
        }
        let firstChar = charString.charCodeAt(0);
        if (charString.length == 1
            || firstChar < 0xD800
            || firstChar > 0xDBFF) {
            return new Char(firstChar);
        }
        let secondChar = charString.charCodeAt(1);
        if (secondChar < 0xDC00
            || secondChar > 0xDFFF) {
            return new Char(0xFFFD);
        }
        return new Char(0x10000 + ((firstChar - 0xD800) * 0x400) + (secondChar - 0xDC00));
    }
    filter(value) {
        if (value === undefined) {
            return 0;
        }
        if (value instanceof ValueType_1.default) {
            value = value.valueOf();
        }
        if (value < 0
            || value == 0xFFFE
            || value == 0xFFFF
            || value > 0x10FFFF) {
            return 0xFFFD;
        }
        else {
            return value;
        }
    }
    getType() {
        return new Type_1.default(this, package_1.default);
    }
    toString() {
        let value = this.valueOf();
        if (value < 0x10000) {
            return Environment_1.default.ESSTRING.fromCharCode(value);
        }
        value = (value - 0x10000);
        return Environment_1.default.ESSTRING.fromCharCode(((value >> 10) + 0xD800), ((value % 0x400) + 0xDC00));
    }
}
exports.Char = Char;
exports.default = Char;
