/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Char from './Char';
import Type from '../Type';
import ValueType from './ValueType';
/**
 * The string class represent a text string and provides functions for
 * analysation and manipulation.
 *
 * @extends ValueType
 */
export declare class String extends ValueType<string> {
    /**
     * Represents an empty string.
     */
    static readonly EMPTY: String;
    private _chars;
    private _length;
    /**
     * Provides access to the unicode chars of this string.
     */
    readonly chars: Char[];
    /**
     * The length of this text string.
     */
    readonly length: number;
    /**
     * Determines whether the ending of this text string matches the provided
     * string value.
     *
     * @param {string|String} other
     * The provided string to compare with this text string.
     *
     * @returns {boolean}
     * True if this text string ends with the provided value, otherwise false.
     */
    endsWith(other: (string | String)): boolean;
    /**
     * Compares this string with an other string for equality.
     *
     * @param {string|String|Object} other
     * The object to compare with.
     *
     * @return {boolean}
     * True, if the objects are equal, otherwise false.
     */
    equals(other: (string | String | Object)): boolean;
    /**
     * Filters the primitive value at initialization.
     *
     * @param {string} value
     * The provided primitive value.
     *
     * @return {string}
     * The filtered primitive value.
     */
    protected filter(value: (string | undefined)): string;
    /**
     * Returns the type of the string for further reflection.
     *
     * @return {Type}
     * The type of this string.
     */
    getType(): Type;
    /**
     * Determines whether the beginning of this text string matches the
     * provided string value.
     *
     * @param {string|String} other
     * The provided string to compare with this text string.
     *
     * @return {boolean}
     * True if this text string begins with the provided value, otherwise
     * false.
     */
    startsWith(other: (string | String)): boolean;
    /**
     * Returns the native object without any conversion.
     *
     * @return {string}
     * The native object without any conversion.
     */
    toString(): string;
}
export default String;
