"use strict";
/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
Object.defineProperty(exports, "__esModule", { value: true });
const package_1 = require("../../package");
const Char_1 = require("./Char");
const Type_1 = require("../Type");
const ValueType_1 = require("./ValueType");
class String extends ValueType_1.default {
    constructor() {
        super(...arguments);
        this._chars = undefined;
        this._length = undefined;
    }
    get chars() {
        if (this._chars === undefined) {
            let newChars = [];
            this.valueOf().split(UNICODE_REGEXP).forEach((charString) => {
                newChars.push(Char_1.default.tryParse(charString));
            });
            this._chars = newChars;
        }
        return this._chars;
    }
    get length() {
        if (this._length === undefined) {
            this._length = this.valueOf().replace(UNICODE_REGEXP, '_').length;
        }
        return this._length;
    }
    endsWith(other) {
        other = other.toString();
        if (other == '') {
            return true;
        }
        let rawValue = this.valueOf();
        let index = rawValue.lastIndexOf(other);
        return (index >= 0
            && index == (rawValue.length - other.length));
    }
    equals(other) {
        if (typeof other == 'string') {
            return (other === this.valueOf());
        }
        else {
            return (other instanceof ValueType_1.default
                && other.valueOf() == this.valueOf()
                && other.getType().equals(this.getType()));
        }
    }
    filter(value) {
        return (value ? value.toString() : '');
    }
    getType() {
        return new Type_1.default(this, package_1.default);
    }
    startsWith(other) {
        other = other.toString();
        return (other == ''
            || this.valueOf().indexOf(other) == 0);
    }
    toString() {
        return this.valueOf();
    }
}
String.EMPTY = new String();
exports.String = String;
exports.default = String;
const UNICODE_REGEXP = new RegExp('[\\uD800-\\uDBFF][\\uDC00-\\uDFFF]|[\s\S]', 'g');
