/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import Object from '../Object';
import Type from '../Type';
export declare abstract class ValueType<T extends (boolean | number | string)> extends Object {
    /**
     * Initialize the value type with a provided primitive value.
     * @param {boolean|number|string|ValueType|undefined} values The primitive value of this value type.
     */
    constructor(value?: (T | ValueType<T>));
    private _hashCode;
    private _value;
    /**
     * Filters the primitive value at initialization.
     * @param {boolean|number|string|ValueType|undefined} value The provided primitive value.
     * @return {boolean|number|string} The filtered primitive value.
     */
    protected abstract filter(value: (T | ValueType<T> | undefined)): T;
    /**
     * Returns the type of this value type for further reflection.
     * @return {Type} The type of this value type.
     */
    abstract getType(): Type;
    /**
     * Compares this value type with an other object for equality.
     * @param {ValueType|Object} other The object to compare with.
     * @return {boolean} True, if the objects are equal, otherwise false.
     */
    equals(other: (ValueType<T> | Object)): boolean;
    /**
     * Generates a unique code for this value type.
     * @return {number} Returns the unique code for this value type.
     */
    getHashCode(): number;
    /**
     * Returns the string representation of this value type.
     * @return {string} The string representation of this value type.
     */
    toString(): string;
    /**
     * Returns the primitive value of this value type.
     * @return {boolean|number|string} The primitive value of this value type.
     */
    valueOf(): T;
}
export default ValueType;
