/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
import IPackageMetaData from './Runtime/IPackageMetaData';
import Object from './Object';
/**
 * The type class of an object provides information for further reflection.
 *
 * @extends Object
 */
export declare class Type extends Object {
    /**
     * Loads a class and returns its type.
     *
     * @param {string} name
     * The name of the class.
     *
     * @param {string} packageName
     * The name of the package.
     *
     * @returns {Type|undefind}
     * The type of the class.
     */
    static of(name: string, packageName?: string): (Type | undefined);
    /**
     * Creates the class type of a given object.
     *
     * @param {Object} object
     * An instance object of the class.
     *
     * @param {IPackageMetaData} IPackageMetaData
     * The meta data of the object package.
     */
    constructor(object: Object, packageMetaData: IPackageMetaData);
    private _constructor;
    private _hashCode;
    private _name;
    private _numberOfArguments;
    private _packageMetaData;
    /**
     * The constructor of the class.
     */
    readonly classConstructor: Function;
    /**
     * The full class name.
     */
    readonly fullName: string;
    /**
     * The class name.
     */
    readonly name: String;
    /**
     * The name of the package of this class.
     */
    readonly packageName: String;
    /**
     * Compares this object type with another object type.
     *
     * @param {Type|Object} other
     * The other object or type to compare with.
     *
     * @returns {boolean}
     * Returns true, if the objects are equal, otherwise false.
     */
    equals(other: (Type | Object)): boolean;
    /**
     * Generates a unique code for this type.
     *
     * @return {number}
     * Returns the unique code for this type.
     */
    getHashCode(): number;
    /**
     * Returns itself for further reflection.
     *
     * @returns {Type}
     * Returns this type.
     */
    getType(): Type;
    /**
     * Returns the full name of the representing class.
     *
     * @return {string}
     * Returns the full class name.
     */
    toString(): string;
    /**
     * Returns the full name of the representing class.
     *
     * @return {string}
     * Returns the full class name.
     */
    valueOf(): string;
}
export default Type;
