"use strict";
/*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*!*\

  System Core TypeScript Library

  Copyright (c) TypeScriptLibs and Contributors

  Licensed under the MIT License; you may not use this file except in
  compliance with the License. You may obtain a copy of the MIT License at
  https://typescriptlibs.org/LICENSE.txt

\*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*i*/
Object.defineProperty(exports, "__esModule", { value: true });
const Object_1 = require("./Object");
const RuntimeUtility_1 = require("./Runtime/RuntimeUtility");
class Type extends Object_1.default {
    static of(name, packageName) {
        let imported_module = require(packageName || 'tsl-system-core');
        if (imported_module) {
            return new Type({ 'constructor': imported_module[name] }, imported_module);
        }
        else {
            return undefined;
        }
    }
    constructor(object, packageMetaData) {
        super();
        this._constructor = object.constructor;
        this._packageMetaData = packageMetaData;
        this._name = (this._constructor.name == '_Object_' ? 'Object' : this._constructor.name);
        this._numberOfArguments = object.constructor.length;
    }
    get classConstructor() {
        return this._constructor;
    }
    get fullName() {
        return (this.packageName + '.' + this.name);
    }
    get name() {
        return this._name;
    }
    get packageName() {
        return this._packageMetaData.name;
    }
    equals(other) {
        return (other instanceof Type
            && other.fullName === this.fullName);
    }
    getHashCode() {
        if (this._hashCode === undefined) {
            this._hashCode = RuntimeUtility_1.default.generateStringHashCode(this.fullName.valueOf());
        }
        return this._hashCode;
    }
    getType() {
        return this;
    }
    toString() {
        return this.fullName;
    }
    valueOf() {
        return this.fullName;
    }
}
exports.Type = Type;
exports.default = Type;
